@@ -1,5 +1,5 @@
 # UMLS::Interface 
-# (Last Updated $Id: Interface.pm,v 1.146 2015/12/29 17:51:41 btmcinnes Exp $)
+# (Last Updated $Id: Interface.pm,v 1.147 2016/01/07 22:49:33 btmcinnes Exp $)
 #
 # Perl module that provides a perl interface to the
 # Unified Medical Language System (UMLS)
@@ -421,7 +421,7 @@ my $pkg = "UMLS::Interface";
 
 use vars qw($VERSION);
 
-$VERSION = '1.45';
+$VERSION = '1.47';
 
 my $debug = 0;
 
@@ -1759,6 +1759,39 @@ sub findMaximumDepth {
     return $depth;
 }    
 
+
+=head3 findNumberOfCloserConcepts
+
+description:
+
+ function that finds the DUI of a given CUI
+
+input:   
+
+ $concept  <- the concept
+
+output:
+
+ $dui <- the MSH DUI
+
+example:
+
+ use UMLS::Interface;
+ my $umls = UMLS::Interface->new(); 
+ my $concept  = "C0018563";
+ my $cui       = $umls->getDUI($concept); 
+ print "The DUI for $concept is $dui\n";
+
+=cut
+sub getDUI {
+    my $self = shift;
+    my $concept = shift; 
+
+    my $dui = $cuifinder->_getDUI($concept);
+
+    return $dui;
+}
+
 =head3 findNumberOfCloserConcepts
 
 description:
@@ -1783,7 +1816,6 @@ example:
  my $int       = $umls->findNumberOfCloserConcepts($concept1,$concept2);
  print "The number of closer concepts to $concept1 than $concept2 is $int\n";
 
-
 =cut
 sub findNumberOfCloserConcepts {
 
