@@ -172,31 +172,26 @@ if(defined $opt_username) {
     $option_hash{"username"} = $opt_username;            
 }                
 if(defined $opt_driver) {               
-    $option_hash{"driver"}   = "mysql"; 
+    $option_hash{"driver"}   = $opt_driver;
 }                
 if(defined $opt_database) {             
-    $option_hash{"database"} = $database;                
+    $option_hash{"database"} = $opt_database;                
 }                
 if(defined $opt_password) {             
     $option_hash{"password"} = $opt_password;            
 }                
 if(defined $opt_hostname) {             
-    $option_hash{"hostname"} = $hostname;                
+    $option_hash{"hostname"} = $opt_hostname;                
 }                
 if(defined $opt_socket) {               
-    $option_hash{"socket"}   = $socket; 
+    $option_hash{"socket"}   = $opt_socket; 
 }                
 
 $umls = UMLS::Interface->new(\%option_hash);             
 die "Unable to create UMLS::Interface object.\n" if(!$umls);                    
-($errCode, $errString) = $umls->getError();              
-die "$errString\n" if($errCode);               
-
-&errorCheck($umls);
 
 if(defined $opt_config) {
     my $hashRef = $umls->returnTableNames();
-    &errorCheck($umls);
     
     my $hashkeys = keys %{$hashRef};
     if($hashkeys > 0) {
@@ -233,15 +228,6 @@ else {
     } $sth->finish();
 }
 
-sub errorCheck
-{
-    my $obj = shift;
-    ($errCode, $errString) = $obj->getError();
-    print STDERR "$errString\n" if($errCode);
-    exit if($errCode > 1);
-}
-
-
 ##############################################################################
 #  function to output minimal usage notes
 ##############################################################################
@@ -288,7 +274,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getTableNames.pl,v 1.5 2010/04/19 16:24:12 btmcinnes Exp $';
+    print '$Id: getTableNames.pl,v 1.7 2011/08/29 16:37:03 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
